/////////////////////////////////////////////////////////////////////////////
// Name:      MediaListBox.cpp
// Author:    Alex Thuering
// Created:   7.07.2012
// Copyright: (c) Alex Thuering
// Licence:   GPL
/////////////////////////////////////////////////////////////////////////////

#include "MediaListBox.h"
#include "MainWin.h"
#include "utils.h"
#include "../resources/video.png.h"
#include <wx/dc.h>

MediaListBox::MediaListBox(wxWindow *parent, wxWindowID id, const wxPoint& pos,
		const wxSize& size, long style, int i1, int i2, const wxValidator& val, const wxString& name) :
	wxVListBox(parent, id, pos, size, style, name), files(((MainWin*) parent)->GetFiles()) {
}

void MediaListBox::RefreshAll() {
	SetItemCount(files.size());
	wxVListBox::RefreshAll();
}

void MediaListBox::OnDrawItem(wxDC& dc, const wxRect& rect, size_t idx) const {
	// image
	wxBitmap image = wxBITMAP_FROM_MEMORY(video);
	dc.DrawBitmap(image, rect.x + 2, rect.y + 2);
	int x = rect.x + image.GetWidth() + 6;
	int y = rect.y + 4;

	// text
	dc.SetFont(wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT));
	dc.SetTextForeground((int)idx == GetSelection() ? wxSystemSettings::GetColour(wxSYS_COLOUR_LISTBOXHIGHLIGHTTEXT)
			: wxSystemSettings::GetColour(wxSYS_COLOUR_LISTBOXTEXT));
	dc.DrawText(files[idx]->GetFileName(), x, y);
	y += dc.GetCharHeight() + 2;
	
	long size = files[idx]->GetSize();
	wxString sizeStr = _("Size");
	if (size > 1024*1024)
		sizeStr += wxString::Format(wxT(": %0.1f "), (double) size / 1024 / 1024) + _("GB");
	else if (size > 1024)
		sizeStr += wxString::Format(wxT(": %ld "), size / 1024) + _("MB");
	else
		sizeStr += wxString::Format(wxT(": %ld "), size) + _("KB");
	dc.DrawText(sizeStr, x, y);
}

wxCoord MediaListBox::OnMeasureItem(size_t idx) const {
	return 48;
}
